Add ObjectManager to the root path of the log manager

The ObjectManager needs to be added to the top most
path of the dbus objects that it manages, so need to
initialize it with Logging/ and it'd manage the
Logging/Internal/ and Logging/Entry/ objects.

Fixes openbmc/openbmc#1170.

Change-Id: Ie659a2deaed2967ebca326a86b2e7fd7e637f784
Signed-off-by: Adriana Kobylak <anoo@linux.vnet.ibm.com>
diff --git a/log_manager_main.cpp b/log_manager_main.cpp
index 2d3ccf3..a3b26a3 100644
--- a/log_manager_main.cpp
+++ b/log_manager_main.cpp
@@ -7,8 +7,8 @@
 {
     auto bus = sdbusplus::bus::new_default();
 
-    // Add sdbusplus ObjectManager.
-    sdbusplus::server::manager::manager objManager(bus, OBJ_INTERNAL);
+    // Add sdbusplus ObjectManager for the 'root' path of the logging manager.
+    sdbusplus::server::manager::manager objManager(bus, OBJ_LOGGING);
 
     phosphor::logging::Manager manager(bus, OBJ_INTERNAL);